###################################################
### chunk number 1: preliminaries
###################################################
#line 20 "d:/Rcompile/CRANpkg/local/2.12/ipred/inst/doc/ipred-examples.Rnw"
options(prompt=">", width=50)
set.seed(210477)


###################################################
### chunk number 2: bagging
###################################################
#line 131 "d:/Rcompile/CRANpkg/local/2.12/ipred/inst/doc/ipred-examples.Rnw"
library(ipred)
data(GlaucomaM)
gbag <- bagging(Class ~ ., data = GlaucomaM, coob=TRUE)


###################################################
### chunk number 3: print-bagging
###################################################
#line 143 "d:/Rcompile/CRANpkg/local/2.12/ipred/inst/doc/ipred-examples.Rnw"
print(gbag)


###################################################
### chunk number 4: double-bagging
###################################################
#line 154 "d:/Rcompile/CRANpkg/local/2.12/ipred/inst/doc/ipred-examples.Rnw"
scomb <- list(list(model=slda, predict=function(object, newdata)
  predict(object, newdata)$x))
gbagc <- bagging(Class ~ ., data = GlaucomaM, comb=scomb)


###################################################
### chunk number 5: predict.bagging
###################################################
#line 161 "d:/Rcompile/CRANpkg/local/2.12/ipred/inst/doc/ipred-examples.Rnw"
predict(gbagc, newdata=GlaucomaM[c(1:3, 99:102), ])


###################################################
### chunk number 6: indirect.formula
###################################################
#line 201 "d:/Rcompile/CRANpkg/local/2.12/ipred/inst/doc/ipred-examples.Rnw"
data(GlaucomaMVF)
GlaucomaMVF <- GlaucomaMVF[,-63]
formula.indirect <- Class~clv + lora + cs ~ .


###################################################
### chunk number 7: indirect.fit
###################################################
#line 210 "d:/Rcompile/CRANpkg/local/2.12/ipred/inst/doc/ipred-examples.Rnw"
classify <- function (data) {
  attach(data)
  res <- ifelse((!is.na(clv) & !is.na(lora) & clv >= 5.1 & lora >=
        49.23372) | (!is.na(clv) & !is.na(lora) & !is.na(cs) &
        clv < 5.1 & lora >= 58.55409 & cs < 1.405) | (is.na(clv) &
        !is.na(lora) & !is.na(cs) & lora >= 58.55409 & cs < 1.405) |
        (!is.na(clv) & is.na(lora) & cs < 1.405), 0, 1)
  detach(data)
  factor (res, labels = c("glaucoma", "normal"))
}
fit <- inclass(formula.indirect, pFUN = list(list(model = lm)), 
  cFUN = classify, data = GlaucomaMVF)


###################################################
### chunk number 8: print.indirect
###################################################
#line 226 "d:/Rcompile/CRANpkg/local/2.12/ipred/inst/doc/ipred-examples.Rnw"
print(fit)


###################################################
### chunk number 9: predict.indirect
###################################################
#line 236 "d:/Rcompile/CRANpkg/local/2.12/ipred/inst/doc/ipred-examples.Rnw"
predict(object = fit, newdata = GlaucomaMVF[c(1:3, 86:88),])


###################################################
### chunk number 10: bagging.indirect
###################################################
#line 244 "d:/Rcompile/CRANpkg/local/2.12/ipred/inst/doc/ipred-examples.Rnw"
mypredict.rpart <- function(object, newdata) {
  RES <- predict(object, newdata)
  RET <- rep(NA, nrow(newdata))
  NAMES <- rownames(newdata)
  RET[NAMES %in% names(RES)] <- RES[NAMES[NAMES %in% names(RES)]]
  RET
}
fit <- inbagg(formula.indirect, pFUN = list(list(model = rpart, predict =
mypredict.rpart)), cFUN = classify, nbagg = 25,  data = GlaucomaMVF)


###################################################
### chunk number 11: plda
###################################################
#line 280 "d:/Rcompile/CRANpkg/local/2.12/ipred/inst/doc/ipred-examples.Rnw"
mypredict.lda <- function(object, newdata){    
  predict(object, newdata = newdata)$class
}


###################################################
### chunk number 12: cvlda
###################################################
#line 287 "d:/Rcompile/CRANpkg/local/2.12/ipred/inst/doc/ipred-examples.Rnw"
errorest(Class ~ ., data= GlaucomaM, 
  model=lda, estimator = "cv", predict= mypredict.lda)


###################################################
### chunk number 13: cvindirect
###################################################
#line 296 "d:/Rcompile/CRANpkg/local/2.12/ipred/inst/doc/ipred-examples.Rnw"
errorest(formula.indirect, 
  data = GlaucomaMVF, model = inclass, 
  estimator = "632plus", 
  pFUN = list(list(model = lm)), cFUN = classify)


###################################################
### chunk number 14: varsel-def
###################################################
#line 319 "d:/Rcompile/CRANpkg/local/2.12/ipred/inst/doc/ipred-examples.Rnw"
mymod <- function(formula, data, level=0.05) {
  # select all predictors that are associated with an
  # univariate t.test p-value of less that level
  sel <- which(lapply(data, function(x) {
    if (!is.numeric(x))
      return(1)
    else 
     return(t.test(x ~ data$Class)$p.value)
    }) < level)
  # make sure that the response is still there
  sel <- c(which(colnames(data) %in% "Class"), sel)
  # compute a LDA using the selected predictors only
  mod <- lda(formula , data=data[,sel]) 
  # and return a function for prediction
  function(newdata) {
    predict(mod, newdata=newdata[,sel])$class
  }
}


###################################################
### chunk number 15: varsel-comp
###################################################
#line 348 "d:/Rcompile/CRANpkg/local/2.12/ipred/inst/doc/ipred-examples.Rnw"
errorest(Class ~ . , data=GlaucomaM, model=mymod, estimator = "cv",
est.para=control.errorest(k=5))


